# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeAutoScalingHistoryRequest(DaraModel):
    def __init__(
        self,
        auto_scaling_task_type: str = None,
        end_time: int = None,
        instance_id: str = None,
        start_time: int = None,
    ):
        # The type of the auto scaling task that you want to query. Set the value to **SPEC**, which indicates that you can query the history of only automatic performance scaling tasks.
        # 
        # This parameter is required.
        self.auto_scaling_task_type = auto_scaling_task_type
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # > The end time must be later than the start time.
        # 
        # This parameter is required.
        self.end_time = end_time
        # The instance ID.
        # 
        # > Only ApsaraDB RDS for MySQL instances are supported.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # > The maximum time range that can be specified is 45 days.
        # 
        # This parameter is required.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_scaling_task_type is not None:
            result['AutoScalingTaskType'] = self.auto_scaling_task_type

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoScalingTaskType') is not None:
            self.auto_scaling_task_type = m.get('AutoScalingTaskType')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class EnableSqlConcurrencyControlRequest(DaraModel):
    def __init__(
        self,
        concurrency_control_time: int = None,
        console_context: str = None,
        instance_id: str = None,
        max_concurrency: int = None,
        sql_keywords: str = None,
        sql_type: str = None,
    ):
        # The duration within which the SQL throttling rule takes effect. Unit: seconds.
        # 
        # >  The throttling rule takes effect only within this duration.
        # 
        # This parameter is required.
        self.concurrency_control_time = concurrency_control_time
        # The reserved parameter.
        self.console_context = console_context
        # The instance ID.
        # 
        # >  You must specify the instance ID only if your database instance is an ApsaraDB RDS for MySQL instance or a PolarDB for MySQL cluster.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The maximum number of concurrent SQL statements. Set this parameter to a positive integer.
        # 
        # >  When the number of concurrent SQL statements that contain the specified keywords reaches this upper limit, the throttling rule is triggered.
        # 
        # This parameter is required.
        self.max_concurrency = max_concurrency
        # The keywords that are used to identify the SQL statements that need to be throttled.
        # 
        # >  If you specify multiple SQL keywords, separate them with tildes (~). If the number of concurrent SQL statements that contain all the specified SQL keywords reaches the specified upper limit, the throttling rule is triggered.
        # 
        # This parameter is required.
        self.sql_keywords = sql_keywords
        # The type of the SQL statements. Valid values:
        # 
        # *   **SELECT**
        # *   **UPDATE**
        # *   **DELETE**
        # 
        # This parameter is required.
        self.sql_type = sql_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.concurrency_control_time is not None:
            result['ConcurrencyControlTime'] = self.concurrency_control_time

        if self.console_context is not None:
            result['ConsoleContext'] = self.console_context

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.max_concurrency is not None:
            result['MaxConcurrency'] = self.max_concurrency

        if self.sql_keywords is not None:
            result['SqlKeywords'] = self.sql_keywords

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConcurrencyControlTime') is not None:
            self.concurrency_control_time = m.get('ConcurrencyControlTime')

        if m.get('ConsoleContext') is not None:
            self.console_context = m.get('ConsoleContext')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('MaxConcurrency') is not None:
            self.max_concurrency = m.get('MaxConcurrency')

        if m.get('SqlKeywords') is not None:
            self.sql_keywords = m.get('SqlKeywords')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeCloudbenchTaskResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeCloudbenchTaskResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information, including the error codes and the number of entries that are returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**: The request was successful.
        # *   **false**: The request failed.
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeCloudbenchTaskResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeCloudbenchTaskResponseBodyData(DaraModel):
    def __init__(
        self,
        archive_job_id: str = None,
        archive_oss_table_name: str = None,
        archive_state: int = None,
        backup_id: str = None,
        backup_type: str = None,
        bench_step: str = None,
        bench_step_status: str = None,
        client_gateway_id: str = None,
        client_type: str = None,
        description: str = None,
        dst_instance_uuid: str = None,
        dst_ip: str = None,
        dst_port: int = None,
        dst_type: str = None,
        dts_job_class: str = None,
        dts_job_id: str = None,
        dts_job_name: str = None,
        dts_job_state: int = None,
        dts_job_status: str = None,
        ecs_instance_id: str = None,
        end_state: str = None,
        error_code: str = None,
        error_message: str = None,
        external: str = None,
        rate: int = None,
        request_duration: int = None,
        smart_pressure_time: int = None,
        source: str = None,
        sql_complete_reuse: str = None,
        src_instance_area: str = None,
        src_instance_uuid: str = None,
        src_public_ip: str = None,
        state: str = None,
        status: str = None,
        table_schema: str = None,
        task_id: str = None,
        task_type: str = None,
        topic: str = None,
        user_id: str = None,
        version: str = None,
        work_dir: str = None,
    ):
        # The ID of the archiving task.
        self.archive_job_id = archive_job_id
        # The name of the table that was archived to Object Storage Service (OSS).
        self.archive_oss_table_name = archive_oss_table_name
        # The archiving state of the file that stores the analysis result of full SQL statistics. Valid values:
        # 
        # *   **0**: The file archiving is not started.
        # *   **1**: The file is archived.
        # *   **2**: An error occurred.
        # *   **3**: The file is being archived.
        # *   **4**: The archived file does not need to be downloaded.
        self.archive_state = archive_state
        # The ID of the backup set. You can call the [DescribeBackups](https://help.aliyun.com/document_detail/26273.html) operation to query the ID of the backup set.
        self.backup_id = backup_id
        # The backup type. Valid values:
        # 
        # *   **TIMESTAMP**
        # *   **BACKUPID**
        self.backup_type = backup_type
        # The substep in the stress testing task. Valid values:
        # 
        # *   **NEW**: initializes the stress testing task.
        # *   **WAIT_BUY_ECS**: purchases an ECS instance.
        # *   **WAIT_START_ECS**: starts an ECS instance.
        # *   **WAIT_INSTALL_JDK**: installs the Java Development Kit (JDK).
        # *   **WAIT_INSTALL_DBGATEWAY**: installs the database gateway (DBGateway).
        # *   **ADD_SECURITY_IPS_STEP**: configure a security group whitelist.
        # *   **ARCHIVE**: archives the full SQL statistics.
        # *   **DOWNLOAD**: downloads the file that stores the analysis result of full SQL statistics.
        # *   **PROCEED**: preprocesses the file that stores the analysis result of full SQL statistics.
        # *   **PRE_LOAD**: preloads the file that stores the analysis result of full SQL statistics.
        # *   **VALIDATE**: verifies the functionality of stress testing.
        # *   **PRESSURE**: starts the stress testing task.
        self.bench_step = bench_step
        # The status that indicates the substep performed on the stress testing task. Valid values:
        # 
        # *   **NEW**: The task is being initialized.
        # *   **RUNNING**: The task is running.
        # *   **FAILED**: The task failed.
        # *   **FINISHED**: The task is complete.
        # *   **Terminated**: The task is terminated.
        # *   **Deleted**: The task is deleted.
        self.bench_step_status = bench_step_status
        # The DBGateway ID of the stress testing client.
        self.client_gateway_id = client_gateway_id
        # The type of the stress testing client. Valid values:
        # 
        # *   **ECS**: indicates that you must create the [DBGateway](https://help.aliyun.com/document_detail/64905.html).
        # *   **DAS_ECS**: indicates that DAS automatically purchases and deploys an ECS instance for stress testing.
        self.client_type = client_type
        # The description of the stress testing task.
        self.description = description
        # The UUID of the destination instance.
        self.dst_instance_uuid = dst_instance_uuid
        # The reserved parameter.
        self.dst_ip = dst_ip
        # The port number of the destination instance.
        self.dst_port = dst_port
        # The type of the identifier that is used to indicate the destination instance. Valid values:
        # 
        # *   **Instance** (default): the instance ID.
        # *   **ConnectionString**: the endpoint of the instance.
        self.dst_type = dst_type
        # The specification of the DTS task.
        self.dts_job_class = dts_job_class
        # The ID of the DTS migration task.
        self.dts_job_id = dts_job_id
        # The name of the Data Transmission Service (DTS) task.
        self.dts_job_name = dts_job_name
        # The state of the DTS task. Valid values:
        # 
        # *   **NOT_STARTED**: The task is not started.
        # *   **PRE_CHECKING**: The task is in precheck.
        # *   **PRE_CHECK_FAILED**: The precheck failed.
        # *   **CHECKING**: The task is being checked.
        # *   **MIGRATING**: The data is being migrated.
        # *   **CATCHED**: The data is migrated from the source instance to the destination instance.
        # *   **SUSPENDING**: The task is suspended.
        # *   **MIGRATION_FAILED**: The data failed to be migrated.
        # *   **FINISHED**: The task is complete.
        # *   **INITIALIZING**: The synchronization is being initialized.
        # *   **INITIALIZE_FAILED**: The synchronization failed to be initialized.
        # *   **SYNCHRONIZING**: The data is being synchronized.
        # *   **MODIFYING**: The objects to be synchronized are being changed.
        # *   **SWITCHING**: The roles of the instances are being switched.
        # *   **FAILED**: The task failed.
        self.dts_job_state = dts_job_state
        # The state of the DTS task. Valid values:
        # 
        # *   **NOT_STARTED**: The task is not started.
        # *   **PRE_CHECKING**: The task is in precheck.
        # *   **PRE_CHECK_FAILED**: The precheck failed.
        # *   **CHECKING**: The task is being checked.
        # *   **MIGRATING**: The data is being migrated.
        # *   **CATCHED**: The data is migrated from the source instance to the destination instance.
        # *   **SUSPENDING**: The task is suspended.
        # *   **MIGRATION_FAILED**: The data failed to be migrated.
        # *   **FINISHED**: The task is complete.
        # *   **INITIALIZING**: The synchronization is being initialized.
        # *   **INITIALIZE_FAILED**: The synchronization failed to be initialized.
        # *   **SYNCHRONIZING**: The data is being synchronized.
        # *   **MODIFYING**: The objects to be synchronized are being changed.
        # *   **SWITCHING**: The roles of the instances are being switched.
        # *   **FAILED**: The task failed.
        self.dts_job_status = dts_job_status
        # The ID of the Elastic Compute Service (ECS) instance.
        self.ecs_instance_id = ecs_instance_id
        # The state that specifies the last operation that is performed for the stress testing task. Valid values:
        # 
        # *   **WAIT_TARGET**: prepares the destination instance.
        # *   **WAIT_DBGATEWAY**: prepares the DBGateway.
        # *   **WAIT_SQL**: prepares the full SQL statistics.
        # *   **WAIT_LOGIC**: prepares to replay the traffic.
        # 
        # >  When the state of a stress testing task changes to the state that is specified by the EndState parameter, the stress testing task becomes completed.
        self.end_state = end_state
        # The error code returned for the substep of the stress testing task.
        self.error_code = error_code
        # The error message returned if the request failed.
        self.error_message = error_message
        # The additional information.
        self.external = external
        # The rate at which the stress testing task replayed the traffic. The value is a positive integer. Valid values:**1** to **30**. Default value: **1**.
        self.rate = rate
        # The duration of the stress testing task for which traffic was captured from the source instance.
        self.request_duration = request_duration
        # The duration of the stress testing task for which the traffic was generated on the destination instance. Unit: milliseconds.
        self.smart_pressure_time = smart_pressure_time
        # The source of the task. Valid values:
        # 
        # *   **DAS**
        # *   **OPEN_API**
        self.source = source
        # The reuse information about the analysis result of full SQL statistics.
        self.sql_complete_reuse = sql_complete_reuse
        # The database type of the source instance. Valid values:
        self.src_instance_area = src_instance_area
        # The UUID of the source instance.
        self.src_instance_uuid = src_instance_uuid
        # The reserved parameter.
        self.src_public_ip = src_public_ip
        # The state that indicates the operation performed for the stress testing task. Valid values:
        # 
        # *   **WAIT_TARGET**: prepares the destination instance.
        # *   **WAIT_DBGATEWAY**: prepares the DBGateway.
        # *   **WAIT_SQL**: prepares the full SQL statistics.
        # *   **WAIT_LOGIC**: prepares to replay the traffic.
        self.state = state
        # The state of the stress testing task. Valid values:
        # 
        # *   **SUCCESS**: The task is successful.
        # *   **IGNORED**: The task is ignored.
        # *   **RUNNING**: The task is running.
        # *   **EXCEPTION**: An error occurred.
        self.status = status
        # The name of the table that is used for stress testing.
        self.table_schema = table_schema
        # The task ID.
        self.task_id = task_id
        # The type of the stress testing task. Valid values:
        # 
        # *   **pressure test** (default): A task of this type replays the traffic that is captured from the source instance on the destination instance at the maximum playback rate that is supported by the destination instance.
        # *   **smart pressure test**: A task of this type analyzes the traffic that is captured from the source instance over a short period of time and generates traffic on the destination instance for continuous stress testing. The business model based on which the traffic is generated on the destination instance and the traffic distribution are consistent with those on the source instance. Stress testing tasks of this type can help you reduce the amount of time that is consumed to collect data from the source instance and reduce storage costs and performance overheads.
        self.task_type = task_type
        # The topic that contains the consumed data. This topic is a topic in Message Queue for Apache Kafka.
        self.topic = topic
        # The ID of the Alibaba Cloud account.
        self.user_id = user_id
        # The version of the stress testing task. Valid values:
        # 
        # *   **V2.0**
        # *   **V3.0**
        self.version = version
        # The temporary directory generated for stress testing.
        self.work_dir = work_dir

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.archive_job_id is not None:
            result['ArchiveJobId'] = self.archive_job_id

        if self.archive_oss_table_name is not None:
            result['ArchiveOssTableName'] = self.archive_oss_table_name

        if self.archive_state is not None:
            result['ArchiveState'] = self.archive_state

        if self.backup_id is not None:
            result['BackupId'] = self.backup_id

        if self.backup_type is not None:
            result['BackupType'] = self.backup_type

        if self.bench_step is not None:
            result['BenchStep'] = self.bench_step

        if self.bench_step_status is not None:
            result['BenchStepStatus'] = self.bench_step_status

        if self.client_gateway_id is not None:
            result['ClientGatewayId'] = self.client_gateway_id

        if self.client_type is not None:
            result['ClientType'] = self.client_type

        if self.description is not None:
            result['Description'] = self.description

        if self.dst_instance_uuid is not None:
            result['DstInstanceUuid'] = self.dst_instance_uuid

        if self.dst_ip is not None:
            result['DstIp'] = self.dst_ip

        if self.dst_port is not None:
            result['DstPort'] = self.dst_port

        if self.dst_type is not None:
            result['DstType'] = self.dst_type

        if self.dts_job_class is not None:
            result['DtsJobClass'] = self.dts_job_class

        if self.dts_job_id is not None:
            result['DtsJobId'] = self.dts_job_id

        if self.dts_job_name is not None:
            result['DtsJobName'] = self.dts_job_name

        if self.dts_job_state is not None:
            result['DtsJobState'] = self.dts_job_state

        if self.dts_job_status is not None:
            result['DtsJobStatus'] = self.dts_job_status

        if self.ecs_instance_id is not None:
            result['EcsInstanceId'] = self.ecs_instance_id

        if self.end_state is not None:
            result['EndState'] = self.end_state

        if self.error_code is not None:
            result['ErrorCode'] = self.error_code

        if self.error_message is not None:
            result['ErrorMessage'] = self.error_message

        if self.external is not None:
            result['External'] = self.external

        if self.rate is not None:
            result['Rate'] = self.rate

        if self.request_duration is not None:
            result['RequestDuration'] = self.request_duration

        if self.smart_pressure_time is not None:
            result['SmartPressureTime'] = self.smart_pressure_time

        if self.source is not None:
            result['Source'] = self.source

        if self.sql_complete_reuse is not None:
            result['SqlCompleteReuse'] = self.sql_complete_reuse

        if self.src_instance_area is not None:
            result['SrcInstanceArea'] = self.src_instance_area

        if self.src_instance_uuid is not None:
            result['SrcInstanceUuid'] = self.src_instance_uuid

        if self.src_public_ip is not None:
            result['SrcPublicIp'] = self.src_public_ip

        if self.state is not None:
            result['State'] = self.state

        if self.status is not None:
            result['Status'] = self.status

        if self.table_schema is not None:
            result['TableSchema'] = self.table_schema

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_type is not None:
            result['TaskType'] = self.task_type

        if self.topic is not None:
            result['Topic'] = self.topic

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.version is not None:
            result['Version'] = self.version

        if self.work_dir is not None:
            result['WorkDir'] = self.work_dir

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ArchiveJobId') is not None:
            self.archive_job_id = m.get('ArchiveJobId')

        if m.get('ArchiveOssTableName') is not None:
            self.archive_oss_table_name = m.get('ArchiveOssTableName')

        if m.get('ArchiveState') is not None:
            self.archive_state = m.get('ArchiveState')

        if m.get('BackupId') is not None:
            self.backup_id = m.get('BackupId')

        if m.get('BackupType') is not None:
            self.backup_type = m.get('BackupType')

        if m.get('BenchStep') is not None:
            self.bench_step = m.get('BenchStep')

        if m.get('BenchStepStatus') is not None:
            self.bench_step_status = m.get('BenchStepStatus')

        if m.get('ClientGatewayId') is not None:
            self.client_gateway_id = m.get('ClientGatewayId')

        if m.get('ClientType') is not None:
            self.client_type = m.get('ClientType')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('DstInstanceUuid') is not None:
            self.dst_instance_uuid = m.get('DstInstanceUuid')

        if m.get('DstIp') is not None:
            self.dst_ip = m.get('DstIp')

        if m.get('DstPort') is not None:
            self.dst_port = m.get('DstPort')

        if m.get('DstType') is not None:
            self.dst_type = m.get('DstType')

        if m.get('DtsJobClass') is not None:
            self.dts_job_class = m.get('DtsJobClass')

        if m.get('DtsJobId') is not None:
            self.dts_job_id = m.get('DtsJobId')

        if m.get('DtsJobName') is not None:
            self.dts_job_name = m.get('DtsJobName')

        if m.get('DtsJobState') is not None:
            self.dts_job_state = m.get('DtsJobState')

        if m.get('DtsJobStatus') is not None:
            self.dts_job_status = m.get('DtsJobStatus')

        if m.get('EcsInstanceId') is not None:
            self.ecs_instance_id = m.get('EcsInstanceId')

        if m.get('EndState') is not None:
            self.end_state = m.get('EndState')

        if m.get('ErrorCode') is not None:
            self.error_code = m.get('ErrorCode')

        if m.get('ErrorMessage') is not None:
            self.error_message = m.get('ErrorMessage')

        if m.get('External') is not None:
            self.external = m.get('External')

        if m.get('Rate') is not None:
            self.rate = m.get('Rate')

        if m.get('RequestDuration') is not None:
            self.request_duration = m.get('RequestDuration')

        if m.get('SmartPressureTime') is not None:
            self.smart_pressure_time = m.get('SmartPressureTime')

        if m.get('Source') is not None:
            self.source = m.get('Source')

        if m.get('SqlCompleteReuse') is not None:
            self.sql_complete_reuse = m.get('SqlCompleteReuse')

        if m.get('SrcInstanceArea') is not None:
            self.src_instance_area = m.get('SrcInstanceArea')

        if m.get('SrcInstanceUuid') is not None:
            self.src_instance_uuid = m.get('SrcInstanceUuid')

        if m.get('SrcPublicIp') is not None:
            self.src_public_ip = m.get('SrcPublicIp')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TableSchema') is not None:
            self.table_schema = m.get('TableSchema')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskType') is not None:
            self.task_type = m.get('TaskType')

        if m.get('Topic') is not None:
            self.topic = m.get('Topic')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('Version') is not None:
            self.version = m.get('Version')

        if m.get('WorkDir') is not None:
            self.work_dir = m.get('WorkDir')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateAutoThrottleRulesAsyncRequest(DaraModel):
    def __init__(
        self,
        abnormal_duration: float = None,
        active_sessions: int = None,
        allow_throttle_end_time: str = None,
        allow_throttle_start_time: str = None,
        auto_kill_session: bool = None,
        console_context: str = None,
        cpu_session_relation: str = None,
        cpu_usage: float = None,
        instance_ids: str = None,
        max_throttle_time: float = None,
        result_id: str = None,
    ):
        # The duration threshold for triggering automatic SQL throttling. Set this parameter to an integer that is greater than or equal to 2. Unit: minutes.
        # 
        # This parameter is required.
        self.abnormal_duration = abnormal_duration
        # The threshold for the number of active sessions.
        # 
        # *   If this parameter and CpuUsage are in the **OR** relationship, set this parameter to an integer that is greater than or equal to 16.
        # *   If this parameter and CpuUsage are in the **AND** relationship, set this parameter to an integer that is greater than or equal to 2.
        # 
        # This parameter is required.
        self.active_sessions = active_sessions
        # The end time of the throttling window. The time must be in UTC.
        # 
        # This parameter is required.
        self.allow_throttle_end_time = allow_throttle_end_time
        # The start time of the throttling window. The time must be in UTC.
        # 
        # This parameter is required.
        self.allow_throttle_start_time = allow_throttle_start_time
        # Specifies whether to terminate abnormal SQL statements in execution at the same time. Valid values:
        # 
        # >  Abnormal SQL statements use the same template as the SQL statements to be throttled.
        # 
        # *   **true**
        # *   **false**
        # 
        # This parameter is required.
        self.auto_kill_session = auto_kill_session
        # The reserved parameter.
        self.console_context = console_context
        # The logical relationship between the CPU utilization threshold and the maximum number of active sessions. Valid values:
        # 
        # *   **AND**
        # *   **OR**
        # 
        # This parameter is required.
        self.cpu_session_relation = cpu_session_relation
        # The threshold for CPU utilization. Valid values: 70% to 100%.
        # 
        # This parameter is required.
        self.cpu_usage = cpu_usage
        # The database instance IDs.
        # 
        # >  Set this parameter to a JSON array that consists of multiple instance IDs. Separate instance IDs with commas (,). Example: `[\\"Instance ID1\\", \\"Instance ID2\\"]`.
        # 
        # This parameter is required.
        self.instance_ids = instance_ids
        # The maximum throttling duration. Set this parameter to a positive integer. Unit: minutes.
        # 
        # This parameter is required.
        self.max_throttle_time = max_throttle_time
        # The ID of the asynchronous request.
        # 
        # >  You can leave this parameter empty when you call the operation to initiate the request for the first time, and use the value of this parameter contained in the response to the first request for subsequent requests.
        self.result_id = result_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.abnormal_duration is not None:
            result['AbnormalDuration'] = self.abnormal_duration

        if self.active_sessions is not None:
            result['ActiveSessions'] = self.active_sessions

        if self.allow_throttle_end_time is not None:
            result['AllowThrottleEndTime'] = self.allow_throttle_end_time

        if self.allow_throttle_start_time is not None:
            result['AllowThrottleStartTime'] = self.allow_throttle_start_time

        if self.auto_kill_session is not None:
            result['AutoKillSession'] = self.auto_kill_session

        if self.console_context is not None:
            result['ConsoleContext'] = self.console_context

        if self.cpu_session_relation is not None:
            result['CpuSessionRelation'] = self.cpu_session_relation

        if self.cpu_usage is not None:
            result['CpuUsage'] = self.cpu_usage

        if self.instance_ids is not None:
            result['InstanceIds'] = self.instance_ids

        if self.max_throttle_time is not None:
            result['MaxThrottleTime'] = self.max_throttle_time

        if self.result_id is not None:
            result['ResultId'] = self.result_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AbnormalDuration') is not None:
            self.abnormal_duration = m.get('AbnormalDuration')

        if m.get('ActiveSessions') is not None:
            self.active_sessions = m.get('ActiveSessions')

        if m.get('AllowThrottleEndTime') is not None:
            self.allow_throttle_end_time = m.get('AllowThrottleEndTime')

        if m.get('AllowThrottleStartTime') is not None:
            self.allow_throttle_start_time = m.get('AllowThrottleStartTime')

        if m.get('AutoKillSession') is not None:
            self.auto_kill_session = m.get('AutoKillSession')

        if m.get('ConsoleContext') is not None:
            self.console_context = m.get('ConsoleContext')

        if m.get('CpuSessionRelation') is not None:
            self.cpu_session_relation = m.get('CpuSessionRelation')

        if m.get('CpuUsage') is not None:
            self.cpu_usage = m.get('CpuUsage')

        if m.get('InstanceIds') is not None:
            self.instance_ids = m.get('InstanceIds')

        if m.get('MaxThrottleTime') is not None:
            self.max_throttle_time = m.get('MaxThrottleTime')

        if m.get('ResultId') is not None:
            self.result_id = m.get('ResultId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class AddHDMInstanceResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.AddHDMInstanceResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
        synchro: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information, including the error codes and the number of entries that are returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**: The request was successful.
        # *   **false**: The request failed.
        self.success = success
        # The reserved parameter.
        self.synchro = synchro

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        if self.synchro is not None:
            result['Synchro'] = self.synchro

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.AddHDMInstanceResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('Synchro') is not None:
            self.synchro = m.get('Synchro')

        return self



class AddHDMInstanceResponseBodyData(DaraModel):
    def __init__(
        self,
        caller_uid: str = None,
        code: int = None,
        error: str = None,
        instance_id: str = None,
        ip: str = None,
        owner_id: str = None,
        port: int = None,
        role: str = None,
        tenant_id: str = None,
        token: str = None,
        uuid: str = None,
        vpc_id: str = None,
    ):
        # The user ID of the caller.
        self.caller_uid = caller_uid
        # The HTTP status code returned.
        self.code = code
        # The error message returned if the request failed.
        self.error = error
        # The instance ID.
        self.instance_id = instance_id
        # The endpoint of the instance.
        self.ip = ip
        # The ID of the instance owner.
        self.owner_id = owner_id
        # The port number of the instance that you want to access.
        self.port = port
        # The role of the current API caller.
        self.role = role
        # The tenant ID.
        self.tenant_id = tenant_id
        # The client token that is used to ensure the idempotence of the request.
        self.token = token
        # The unique identifier of the instance.
        self.uuid = uuid
        # The VPC ID.
        self.vpc_id = vpc_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.caller_uid is not None:
            result['CallerUid'] = self.caller_uid

        if self.code is not None:
            result['Code'] = self.code

        if self.error is not None:
            result['Error'] = self.error

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.ip is not None:
            result['Ip'] = self.ip

        if self.owner_id is not None:
            result['OwnerId'] = self.owner_id

        if self.port is not None:
            result['Port'] = self.port

        if self.role is not None:
            result['Role'] = self.role

        if self.tenant_id is not None:
            result['TenantId'] = self.tenant_id

        if self.token is not None:
            result['Token'] = self.token

        if self.uuid is not None:
            result['Uuid'] = self.uuid

        if self.vpc_id is not None:
            result['VpcId'] = self.vpc_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CallerUid') is not None:
            self.caller_uid = m.get('CallerUid')

        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Error') is not None:
            self.error = m.get('Error')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Ip') is not None:
            self.ip = m.get('Ip')

        if m.get('OwnerId') is not None:
            self.owner_id = m.get('OwnerId')

        if m.get('Port') is not None:
            self.port = m.get('Port')

        if m.get('Role') is not None:
            self.role = m.get('Role')

        if m.get('TenantId') is not None:
            self.tenant_id = m.get('TenantId')

        if m.get('Token') is not None:
            self.token = m.get('Token')

        if m.get('Uuid') is not None:
            self.uuid = m.get('Uuid')

        if m.get('VpcId') is not None:
            self.vpc_id = m.get('VpcId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Any, List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetDasSQLLogHotDataResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetDasSQLLogHotDataResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # > If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetDasSQLLogHotDataResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetDasSQLLogHotDataResponseBodyData(DaraModel):
    def __init__(
        self,
        extra: Any = None,
        list: List[main_models.GetDasSQLLogHotDataResponseBodyDataList] = None,
        page_no: int = None,
        page_size: int = None,
        total: int = None,
    ):
        # The reserved parameter.
        self.extra = extra
        # The details of the data returned.
        self.list = list
        # The page number.
        self.page_no = page_no
        # The number of entries per page.
        self.page_size = page_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.extra is not None:
            result['Extra'] = self.extra

        result['List'] = []
        if self.list is not None:
            for k1 in self.list:
                result['List'].append(k1.to_map() if k1 else None)

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Extra') is not None:
            self.extra = m.get('Extra')

        self.list = []
        if m.get('List') is not None:
            for k1 in m.get('List'):
                temp_model = main_models.GetDasSQLLogHotDataResponseBodyDataList()
                self.list.append(temp_model.from_map(k1))

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetDasSQLLogHotDataResponseBodyDataList(DaraModel):
    def __init__(
        self,
        account_name: str = None,
        dbname: str = None,
        execute_time: str = None,
        ext: str = None,
        host_address: str = None,
        latancy: int = None,
        lock_time: int = None,
        logic_read: int = None,
        node_id: str = None,
        origin_time: str = None,
        physic_async_read: int = None,
        physic_sync_read: int = None,
        return_rows: int = None,
        sqltext: str = None,
        scan_rows: int = None,
        sql_type: str = None,
        state: str = None,
        thread_id: int = None,
        transaction_id: str = None,
        update_rows: int = None,
    ):
        # The account of the database.
        self.account_name = account_name
        # The name of the database.
        self.dbname = dbname
        # The execution time. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        self.execute_time = execute_time
        # The extended information. This parameter is a reserved parameter.
        self.ext = ext
        # The IP address of the client.
        self.host_address = host_address
        # The execution duration. Unit: microseconds.
        self.latancy = latancy
        # The lock wait duration. Unit: microseconds.
        self.lock_time = lock_time
        # The number of logical reads.
        self.logic_read = logic_read
        self.node_id = node_id
        # The execution time. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        self.origin_time = origin_time
        # The number of physical asynchronous reads.
        self.physic_async_read = physic_async_read
        # The number of physical synchronous reads.
        self.physic_sync_read = physic_sync_read
        # The number of rows returned.
        self.return_rows = return_rows
        # The content of the SQL statement.
        self.sqltext = sqltext
        # The number of rows scanned by the SQL statement.
        self.scan_rows = scan_rows
        # The type of the SQL statement. Valid values:
        # 
        # * **SELECT**
        # * **UPDATE**
        # * **DELETE**
        self.sql_type = sql_type
        # The execution result. If a **0** is returned, the SQL statement was successfully executed. If an error code is returned, the SQL statement failed to be executed.
        self.state = state
        # The thread ID.
        self.thread_id = thread_id
        # The transaction ID.
        self.transaction_id = transaction_id
        # The number of updated rows.
        self.update_rows = update_rows

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_name is not None:
            result['AccountName'] = self.account_name

        if self.dbname is not None:
            result['DBName'] = self.dbname

        if self.execute_time is not None:
            result['ExecuteTime'] = self.execute_time

        if self.ext is not None:
            result['Ext'] = self.ext

        if self.host_address is not None:
            result['HostAddress'] = self.host_address

        if self.latancy is not None:
            result['Latancy'] = self.latancy

        if self.lock_time is not None:
            result['LockTime'] = self.lock_time

        if self.logic_read is not None:
            result['LogicRead'] = self.logic_read

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.origin_time is not None:
            result['OriginTime'] = self.origin_time

        if self.physic_async_read is not None:
            result['PhysicAsyncRead'] = self.physic_async_read

        if self.physic_sync_read is not None:
            result['PhysicSyncRead'] = self.physic_sync_read

        if self.return_rows is not None:
            result['ReturnRows'] = self.return_rows

        if self.sqltext is not None:
            result['SQLText'] = self.sqltext

        if self.scan_rows is not None:
            result['ScanRows'] = self.scan_rows

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.state is not None:
            result['State'] = self.state

        if self.thread_id is not None:
            result['ThreadID'] = self.thread_id

        if self.transaction_id is not None:
            result['TransactionId'] = self.transaction_id

        if self.update_rows is not None:
            result['UpdateRows'] = self.update_rows

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccountName') is not None:
            self.account_name = m.get('AccountName')

        if m.get('DBName') is not None:
            self.dbname = m.get('DBName')

        if m.get('ExecuteTime') is not None:
            self.execute_time = m.get('ExecuteTime')

        if m.get('Ext') is not None:
            self.ext = m.get('Ext')

        if m.get('HostAddress') is not None:
            self.host_address = m.get('HostAddress')

        if m.get('Latancy') is not None:
            self.latancy = m.get('Latancy')

        if m.get('LockTime') is not None:
            self.lock_time = m.get('LockTime')

        if m.get('LogicRead') is not None:
            self.logic_read = m.get('LogicRead')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('OriginTime') is not None:
            self.origin_time = m.get('OriginTime')

        if m.get('PhysicAsyncRead') is not None:
            self.physic_async_read = m.get('PhysicAsyncRead')

        if m.get('PhysicSyncRead') is not None:
            self.physic_sync_read = m.get('PhysicSyncRead')

        if m.get('ReturnRows') is not None:
            self.return_rows = m.get('ReturnRows')

        if m.get('SQLText') is not None:
            self.sqltext = m.get('SQLText')

        if m.get('ScanRows') is not None:
            self.scan_rows = m.get('ScanRows')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('ThreadID') is not None:
            self.thread_id = m.get('ThreadID')

        if m.get('TransactionId') is not None:
            self.transaction_id = m.get('TransactionId')

        if m.get('UpdateRows') is not None:
            self.update_rows = m.get('UpdateRows')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSqlLogTasksRequest(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        filters: List[main_models.DescribeSqlLogTasksRequestFilters] = None,
        instance_id: str = None,
        node_id: str = None,
        page_no: int = None,
        page_size: int = None,
        start_time: int = None,
    ):
        # The end of the time range to query. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.end_time = end_time
        # The filter parameters.
        self.filters = filters
        # The ID of the database instance.
        self.instance_id = instance_id
        # The node ID.
        # 
        # >  This parameter is available only for instances that are deployed in the cluster architecture. You can specify this parameter to query the tasks of a specific node. If this parameter is not specified, the tasks of the primary node are returned by default.
        self.node_id = node_id
        # The page number. Pages start from page 1. Default value: 1.
        self.page_no = page_no
        # The number of entries per page. Valid values: 1 to 100. Default value: 10.
        self.page_size = page_size
        # The beginning of the time range to query. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start_time = start_time

    def validate(self):
        if self.filters:
            for v1 in self.filters:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        result['Filters'] = []
        if self.filters is not None:
            for k1 in self.filters:
                result['Filters'].append(k1.to_map() if k1 else None)

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        self.filters = []
        if m.get('Filters') is not None:
            for k1 in m.get('Filters'):
                temp_model = main_models.DescribeSqlLogTasksRequestFilters()
                self.filters.append(temp_model.from_map(k1))

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self

class DescribeSqlLogTasksRequestFilters(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The name of the filter parameter.
        # 
        # >  For more information about the filter parameters, see the **Valid values of Key** section of this topic.
        self.key = key
        # The value of the filter parameter.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetAutoResourceOptimizeRulesResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetAutoResourceOptimizeRulesResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetAutoResourceOptimizeRulesResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetAutoResourceOptimizeRulesResponseBodyData(DaraModel):
    def __init__(
        self,
        enable_auto_resource_optimize_count: int = None,
        enable_auto_resource_optimize_list: List[main_models.GetAutoResourceOptimizeRulesResponseBodyDataEnableAutoResourceOptimizeList] = None,
        has_enable_rule_but_not_das_pro_count: int = None,
        has_enable_rule_but_not_das_pro_list: List[main_models.GetAutoResourceOptimizeRulesResponseBodyDataHasEnableRuleButNotDasProList] = None,
        never_enable_auto_resource_optimize_or_released_instance_count: int = None,
        never_enable_auto_resource_optimize_or_released_instance_id_list: List[str] = None,
        total_auto_resource_optimize_rules_count: int = None,
        turn_off_auto_resource_optimize_count: int = None,
        turn_off_auto_resource_optimize_list: List[main_models.GetAutoResourceOptimizeRulesResponseBodyDataTurnOffAutoResourceOptimizeList] = None,
    ):
        # The number of database instances for which the automatic fragment recycling feature is currently enabled.
        self.enable_auto_resource_optimize_count = enable_auto_resource_optimize_count
        # The database instances for which the automatic fragment recycling feature is currently enabled.
        self.enable_auto_resource_optimize_list = enable_auto_resource_optimize_list
        # The number of database instances for which the automatic fragment recycling feature is enabled and DAS Enterprise Edition is disabled.
        self.has_enable_rule_but_not_das_pro_count = has_enable_rule_but_not_das_pro_count
        # The database instances for which the automatic fragment recycling feature is enabled and DAS Enterprise Edition is disabled.
        # 
        # >  Automatic fragment recycling tasks are run on this type of database instances only if DAS Enterprise Edition is enabled for the database instances again.
        self.has_enable_rule_but_not_das_pro_list = has_enable_rule_but_not_das_pro_list
        # The number of database instances that do not exist or for which the automatic fragment recycling feature has never been enabled.
        # 
        # >  If a database instance does not exist, the instance has been released or the specified instance ID is invalid.
        self.never_enable_auto_resource_optimize_or_released_instance_count = never_enable_auto_resource_optimize_or_released_instance_count
        # The database instances that do not exist or for which the automatic fragment recycling feature has never been enabled.
        self.never_enable_auto_resource_optimize_or_released_instance_id_list = never_enable_auto_resource_optimize_or_released_instance_id_list
        # The number of database instances for which the automatic fragment recycling feature has been enabled.
        self.total_auto_resource_optimize_rules_count = total_auto_resource_optimize_rules_count
        # The number of database instances for which the automatic fragment recycling feature was once enabled but is currently disabled.
        self.turn_off_auto_resource_optimize_count = turn_off_auto_resource_optimize_count
        # The database instances for which the automatic fragment recycling feature was once enabled but is currently disabled.
        self.turn_off_auto_resource_optimize_list = turn_off_auto_resource_optimize_list

    def validate(self):
        if self.enable_auto_resource_optimize_list:
            for v1 in self.enable_auto_resource_optimize_list:
                 if v1:
                    v1.validate()
        if self.has_enable_rule_but_not_das_pro_list:
            for v1 in self.has_enable_rule_but_not_das_pro_list:
                 if v1:
                    v1.validate()
        if self.turn_off_auto_resource_optimize_list:
            for v1 in self.turn_off_auto_resource_optimize_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable_auto_resource_optimize_count is not None:
            result['EnableAutoResourceOptimizeCount'] = self.enable_auto_resource_optimize_count

        result['EnableAutoResourceOptimizeList'] = []
        if self.enable_auto_resource_optimize_list is not None:
            for k1 in self.enable_auto_resource_optimize_list:
                result['EnableAutoResourceOptimizeList'].append(k1.to_map() if k1 else None)

        if self.has_enable_rule_but_not_das_pro_count is not None:
            result['HasEnableRuleButNotDasProCount'] = self.has_enable_rule_but_not_das_pro_count

        result['HasEnableRuleButNotDasProList'] = []
        if self.has_enable_rule_but_not_das_pro_list is not None:
            for k1 in self.has_enable_rule_but_not_das_pro_list:
                result['HasEnableRuleButNotDasProList'].append(k1.to_map() if k1 else None)

        if self.never_enable_auto_resource_optimize_or_released_instance_count is not None:
            result['NeverEnableAutoResourceOptimizeOrReleasedInstanceCount'] = self.never_enable_auto_resource_optimize_or_released_instance_count

        if self.never_enable_auto_resource_optimize_or_released_instance_id_list is not None:
            result['NeverEnableAutoResourceOptimizeOrReleasedInstanceIdList'] = self.never_enable_auto_resource_optimize_or_released_instance_id_list

        if self.total_auto_resource_optimize_rules_count is not None:
            result['TotalAutoResourceOptimizeRulesCount'] = self.total_auto_resource_optimize_rules_count

        if self.turn_off_auto_resource_optimize_count is not None:
            result['TurnOffAutoResourceOptimizeCount'] = self.turn_off_auto_resource_optimize_count

        result['TurnOffAutoResourceOptimizeList'] = []
        if self.turn_off_auto_resource_optimize_list is not None:
            for k1 in self.turn_off_auto_resource_optimize_list:
                result['TurnOffAutoResourceOptimizeList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EnableAutoResourceOptimizeCount') is not None:
            self.enable_auto_resource_optimize_count = m.get('EnableAutoResourceOptimizeCount')

        self.enable_auto_resource_optimize_list = []
        if m.get('EnableAutoResourceOptimizeList') is not None:
            for k1 in m.get('EnableAutoResourceOptimizeList'):
                temp_model = main_models.GetAutoResourceOptimizeRulesResponseBodyDataEnableAutoResourceOptimizeList()
                self.enable_auto_resource_optimize_list.append(temp_model.from_map(k1))

        if m.get('HasEnableRuleButNotDasProCount') is not None:
            self.has_enable_rule_but_not_das_pro_count = m.get('HasEnableRuleButNotDasProCount')

        self.has_enable_rule_but_not_das_pro_list = []
        if m.get('HasEnableRuleButNotDasProList') is not None:
            for k1 in m.get('HasEnableRuleButNotDasProList'):
                temp_model = main_models.GetAutoResourceOptimizeRulesResponseBodyDataHasEnableRuleButNotDasProList()
                self.has_enable_rule_but_not_das_pro_list.append(temp_model.from_map(k1))

        if m.get('NeverEnableAutoResourceOptimizeOrReleasedInstanceCount') is not None:
            self.never_enable_auto_resource_optimize_or_released_instance_count = m.get('NeverEnableAutoResourceOptimizeOrReleasedInstanceCount')

        if m.get('NeverEnableAutoResourceOptimizeOrReleasedInstanceIdList') is not None:
            self.never_enable_auto_resource_optimize_or_released_instance_id_list = m.get('NeverEnableAutoResourceOptimizeOrReleasedInstanceIdList')

        if m.get('TotalAutoResourceOptimizeRulesCount') is not None:
            self.total_auto_resource_optimize_rules_count = m.get('TotalAutoResourceOptimizeRulesCount')

        if m.get('TurnOffAutoResourceOptimizeCount') is not None:
            self.turn_off_auto_resource_optimize_count = m.get('TurnOffAutoResourceOptimizeCount')

        self.turn_off_auto_resource_optimize_list = []
        if m.get('TurnOffAutoResourceOptimizeList') is not None:
            for k1 in m.get('TurnOffAutoResourceOptimizeList'):
                temp_model = main_models.GetAutoResourceOptimizeRulesResponseBodyDataTurnOffAutoResourceOptimizeList()
                self.turn_off_auto_resource_optimize_list.append(temp_model.from_map(k1))

        return self

class GetAutoResourceOptimizeRulesResponseBodyDataTurnOffAutoResourceOptimizeList(DaraModel):
    def __init__(
        self,
        auto_defragment: bool = None,
        das_pro_on: bool = None,
        instance_id: str = None,
        table_fragmentation_ratio: float = None,
        table_space_size: float = None,
        user_id: str = None,
    ):
        # Indicates whether the automatic fragment recycling feature is enabled. Valid values:
        # 
        # *   **true**:
        # *   **false**
        self.auto_defragment = auto_defragment
        # Indicates whether DAS Enterprise Edition is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.das_pro_on = das_pro_on
        # The database instance ID.
        self.instance_id = instance_id
        # The fragmentation rate of a single physical table for which the automatic fragment recycling feature is enabled.
        self.table_fragmentation_ratio = table_fragmentation_ratio
        # The minimum storage usage of a single physical table for which the automatic fragment recycling feature is enabled. Unit: GB.
        self.table_space_size = table_space_size
        # The ID of the Alibaba Cloud account that is used to create the database instance.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_defragment is not None:
            result['AutoDefragment'] = self.auto_defragment

        if self.das_pro_on is not None:
            result['DasProOn'] = self.das_pro_on

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.table_fragmentation_ratio is not None:
            result['TableFragmentationRatio'] = self.table_fragmentation_ratio

        if self.table_space_size is not None:
            result['TableSpaceSize'] = self.table_space_size

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoDefragment') is not None:
            self.auto_defragment = m.get('AutoDefragment')

        if m.get('DasProOn') is not None:
            self.das_pro_on = m.get('DasProOn')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('TableFragmentationRatio') is not None:
            self.table_fragmentation_ratio = m.get('TableFragmentationRatio')

        if m.get('TableSpaceSize') is not None:
            self.table_space_size = m.get('TableSpaceSize')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self

class GetAutoResourceOptimizeRulesResponseBodyDataHasEnableRuleButNotDasProList(DaraModel):
    def __init__(
        self,
        auto_defragment: bool = None,
        das_pro_on: bool = None,
        instance_id: str = None,
        table_fragmentation_ratio: float = None,
        table_space_size: float = None,
        user_id: str = None,
    ):
        # Indicates whether the automatic fragment recycling feature is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.auto_defragment = auto_defragment
        # Indicates whether DAS Enterprise Edition is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.das_pro_on = das_pro_on
        # The database instance ID.
        self.instance_id = instance_id
        # The fragmentation rate of a single physical table for which the automatic fragment recycling feature is enabled.
        self.table_fragmentation_ratio = table_fragmentation_ratio
        # The minimum storage usage of a single physical table for which the automatic fragment recycling feature is enabled. Unit: GB.
        self.table_space_size = table_space_size
        # The ID of the Alibaba Cloud account that is used to create the database instance.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_defragment is not None:
            result['AutoDefragment'] = self.auto_defragment

        if self.das_pro_on is not None:
            result['DasProOn'] = self.das_pro_on

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.table_fragmentation_ratio is not None:
            result['TableFragmentationRatio'] = self.table_fragmentation_ratio

        if self.table_space_size is not None:
            result['TableSpaceSize'] = self.table_space_size

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoDefragment') is not None:
            self.auto_defragment = m.get('AutoDefragment')

        if m.get('DasProOn') is not None:
            self.das_pro_on = m.get('DasProOn')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('TableFragmentationRatio') is not None:
            self.table_fragmentation_ratio = m.get('TableFragmentationRatio')

        if m.get('TableSpaceSize') is not None:
            self.table_space_size = m.get('TableSpaceSize')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self

class GetAutoResourceOptimizeRulesResponseBodyDataEnableAutoResourceOptimizeList(DaraModel):
    def __init__(
        self,
        auto_defragment: bool = None,
        das_pro_on: bool = None,
        instance_id: str = None,
        table_fragmentation_ratio: float = None,
        table_space_size: float = None,
        user_id: str = None,
    ):
        # Indicates whether the automatic fragment recycling feature is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.auto_defragment = auto_defragment
        # Indicates whether DAS Enterprise Edition is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.das_pro_on = das_pro_on
        # The database instance ID.
        self.instance_id = instance_id
        # The fragmentation rate of a single physical table for which the automatic fragment recycling feature is enabled.
        self.table_fragmentation_ratio = table_fragmentation_ratio
        # The minimum storage usage of a single physical table for which the automatic fragment recycling feature is enabled. Unit: GB.
        self.table_space_size = table_space_size
        # The ID of the Alibaba Cloud account that is used to create the database instance.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_defragment is not None:
            result['AutoDefragment'] = self.auto_defragment

        if self.das_pro_on is not None:
            result['DasProOn'] = self.das_pro_on

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.table_fragmentation_ratio is not None:
            result['TableFragmentationRatio'] = self.table_fragmentation_ratio

        if self.table_space_size is not None:
            result['TableSpaceSize'] = self.table_space_size

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoDefragment') is not None:
            self.auto_defragment = m.get('AutoDefragment')

        if m.get('DasProOn') is not None:
            self.das_pro_on = m.get('DasProOn')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('TableFragmentationRatio') is not None:
            self.table_fragmentation_ratio = m.get('TableFragmentationRatio')

        if m.get('TableSpaceSize') is not None:
            self.table_space_size = m.get('TableSpaceSize')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeHotBigKeysResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeHotBigKeysResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The list of hot keys and large keys.
        self.data = data
        # The returned message.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**: The request was successful.
        # *   **false**: The request failed.
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeHotBigKeysResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeHotBigKeysResponseBodyData(DaraModel):
    def __init__(
        self,
        big_key_msg: str = None,
        big_keys: main_models.DescribeHotBigKeysResponseBodyDataBigKeys = None,
        high_traffic_key_msg: str = None,
        high_traffic_keys: main_models.DescribeHotBigKeysResponseBodyDataHighTrafficKeys = None,
        hot_key_msg: str = None,
        hot_keys: main_models.DescribeHotBigKeysResponseBodyDataHotKeys = None,
        large_key_msg: str = None,
        large_keys: main_models.DescribeHotBigKeysResponseBodyDataLargeKeys = None,
    ):
        # The reason why the large key failed to be queried.
        self.big_key_msg = big_key_msg
        self.big_keys = big_keys
        self.high_traffic_key_msg = high_traffic_key_msg
        self.high_traffic_keys = high_traffic_keys
        # The reason why the hot key failed to be queried.
        self.hot_key_msg = hot_key_msg
        self.hot_keys = hot_keys
        self.large_key_msg = large_key_msg
        self.large_keys = large_keys

    def validate(self):
        if self.big_keys:
            self.big_keys.validate()
        if self.high_traffic_keys:
            self.high_traffic_keys.validate()
        if self.hot_keys:
            self.hot_keys.validate()
        if self.large_keys:
            self.large_keys.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.big_key_msg is not None:
            result['BigKeyMsg'] = self.big_key_msg

        if self.big_keys is not None:
            result['BigKeys'] = self.big_keys.to_map()

        if self.high_traffic_key_msg is not None:
            result['HighTrafficKeyMsg'] = self.high_traffic_key_msg

        if self.high_traffic_keys is not None:
            result['HighTrafficKeys'] = self.high_traffic_keys.to_map()

        if self.hot_key_msg is not None:
            result['HotKeyMsg'] = self.hot_key_msg

        if self.hot_keys is not None:
            result['HotKeys'] = self.hot_keys.to_map()

        if self.large_key_msg is not None:
            result['LargeKeyMsg'] = self.large_key_msg

        if self.large_keys is not None:
            result['LargeKeys'] = self.large_keys.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BigKeyMsg') is not None:
            self.big_key_msg = m.get('BigKeyMsg')

        if m.get('BigKeys') is not None:
            temp_model = main_models.DescribeHotBigKeysResponseBodyDataBigKeys()
            self.big_keys = temp_model.from_map(m.get('BigKeys'))

        if m.get('HighTrafficKeyMsg') is not None:
            self.high_traffic_key_msg = m.get('HighTrafficKeyMsg')

        if m.get('HighTrafficKeys') is not None:
            temp_model = main_models.DescribeHotBigKeysResponseBodyDataHighTrafficKeys()
            self.high_traffic_keys = temp_model.from_map(m.get('HighTrafficKeys'))

        if m.get('HotKeyMsg') is not None:
            self.hot_key_msg = m.get('HotKeyMsg')

        if m.get('HotKeys') is not None:
            temp_model = main_models.DescribeHotBigKeysResponseBodyDataHotKeys()
            self.hot_keys = temp_model.from_map(m.get('HotKeys'))

        if m.get('LargeKeyMsg') is not None:
            self.large_key_msg = m.get('LargeKeyMsg')

        if m.get('LargeKeys') is not None:
            temp_model = main_models.DescribeHotBigKeysResponseBodyDataLargeKeys()
            self.large_keys = temp_model.from_map(m.get('LargeKeys'))

        return self

class DescribeHotBigKeysResponseBodyDataLargeKeys(DaraModel):
    def __init__(
        self,
        large_key: List[main_models.DescribeHotBigKeysResponseBodyDataLargeKeysLargeKey] = None,
    ):
        self.large_key = large_key

    def validate(self):
        if self.large_key:
            for v1 in self.large_key:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['LargeKey'] = []
        if self.large_key is not None:
            for k1 in self.large_key:
                result['LargeKey'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.large_key = []
        if m.get('LargeKey') is not None:
            for k1 in m.get('LargeKey'):
                temp_model = main_models.DescribeHotBigKeysResponseBodyDataLargeKeysLargeKey()
                self.large_key.append(temp_model.from_map(k1))

        return self

class DescribeHotBigKeysResponseBodyDataLargeKeysLargeKey(DaraModel):
    def __init__(
        self,
        data_size: str = None,
        db: str = None,
        key: str = None,
        key_type: str = None,
        node_id: str = None,
    ):
        self.data_size = data_size
        self.db = db
        self.key = key
        self.key_type = key_type
        self.node_id = node_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data_size is not None:
            result['DataSize'] = self.data_size

        if self.db is not None:
            result['Db'] = self.db

        if self.key is not None:
            result['Key'] = self.key

        if self.key_type is not None:
            result['KeyType'] = self.key_type

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataSize') is not None:
            self.data_size = m.get('DataSize')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('KeyType') is not None:
            self.key_type = m.get('KeyType')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        return self

class DescribeHotBigKeysResponseBodyDataHotKeys(DaraModel):
    def __init__(
        self,
        hot_key: List[main_models.DescribeHotBigKeysResponseBodyDataHotKeysHotKey] = None,
    ):
        self.hot_key = hot_key

    def validate(self):
        if self.hot_key:
            for v1 in self.hot_key:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['HotKey'] = []
        if self.hot_key is not None:
            for k1 in self.hot_key:
                result['HotKey'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.hot_key = []
        if m.get('HotKey') is not None:
            for k1 in m.get('HotKey'):
                temp_model = main_models.DescribeHotBigKeysResponseBodyDataHotKeysHotKey()
                self.hot_key.append(temp_model.from_map(k1))

        return self

class DescribeHotBigKeysResponseBodyDataHotKeysHotKey(DaraModel):
    def __init__(
        self,
        db: int = None,
        hot: str = None,
        key: str = None,
        key_type: str = None,
        lfu: int = None,
        node_id: str = None,
        size: int = None,
    ):
        self.db = db
        self.hot = hot
        self.key = key
        self.key_type = key_type
        self.lfu = lfu
        self.node_id = node_id
        self.size = size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db is not None:
            result['Db'] = self.db

        if self.hot is not None:
            result['Hot'] = self.hot

        if self.key is not None:
            result['Key'] = self.key

        if self.key_type is not None:
            result['KeyType'] = self.key_type

        if self.lfu is not None:
            result['Lfu'] = self.lfu

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.size is not None:
            result['Size'] = self.size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Hot') is not None:
            self.hot = m.get('Hot')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('KeyType') is not None:
            self.key_type = m.get('KeyType')

        if m.get('Lfu') is not None:
            self.lfu = m.get('Lfu')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Size') is not None:
            self.size = m.get('Size')

        return self

class DescribeHotBigKeysResponseBodyDataHighTrafficKeys(DaraModel):
    def __init__(
        self,
        high_traffic_key: List[main_models.DescribeHotBigKeysResponseBodyDataHighTrafficKeysHighTrafficKey] = None,
    ):
        self.high_traffic_key = high_traffic_key

    def validate(self):
        if self.high_traffic_key:
            for v1 in self.high_traffic_key:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['HighTrafficKey'] = []
        if self.high_traffic_key is not None:
            for k1 in self.high_traffic_key:
                result['HighTrafficKey'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.high_traffic_key = []
        if m.get('HighTrafficKey') is not None:
            for k1 in m.get('HighTrafficKey'):
                temp_model = main_models.DescribeHotBigKeysResponseBodyDataHighTrafficKeysHighTrafficKey()
                self.high_traffic_key.append(temp_model.from_map(k1))

        return self

class DescribeHotBigKeysResponseBodyDataHighTrafficKeysHighTrafficKey(DaraModel):
    def __init__(
        self,
        db: int = None,
        hot: str = None,
        key: str = None,
        key_type: str = None,
        node_id: str = None,
        size: int = None,
        in_bytes: int = None,
        out_bytes: int = None,
    ):
        self.db = db
        self.hot = hot
        self.key = key
        self.key_type = key_type
        self.node_id = node_id
        self.size = size
        self.in_bytes = in_bytes
        self.out_bytes = out_bytes

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db is not None:
            result['Db'] = self.db

        if self.hot is not None:
            result['Hot'] = self.hot

        if self.key is not None:
            result['Key'] = self.key

        if self.key_type is not None:
            result['KeyType'] = self.key_type

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.size is not None:
            result['Size'] = self.size

        if self.in_bytes is not None:
            result['inBytes'] = self.in_bytes

        if self.out_bytes is not None:
            result['outBytes'] = self.out_bytes

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Hot') is not None:
            self.hot = m.get('Hot')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('KeyType') is not None:
            self.key_type = m.get('KeyType')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Size') is not None:
            self.size = m.get('Size')

        if m.get('inBytes') is not None:
            self.in_bytes = m.get('inBytes')

        if m.get('outBytes') is not None:
            self.out_bytes = m.get('outBytes')

        return self

class DescribeHotBigKeysResponseBodyDataBigKeys(DaraModel):
    def __init__(
        self,
        big_key: List[main_models.DescribeHotBigKeysResponseBodyDataBigKeysBigKey] = None,
    ):
        self.big_key = big_key

    def validate(self):
        if self.big_key:
            for v1 in self.big_key:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['BigKey'] = []
        if self.big_key is not None:
            for k1 in self.big_key:
                result['BigKey'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.big_key = []
        if m.get('BigKey') is not None:
            for k1 in m.get('BigKey'):
                temp_model = main_models.DescribeHotBigKeysResponseBodyDataBigKeysBigKey()
                self.big_key.append(temp_model.from_map(k1))

        return self

class DescribeHotBigKeysResponseBodyDataBigKeysBigKey(DaraModel):
    def __init__(
        self,
        db: int = None,
        key: str = None,
        key_type: str = None,
        node_id: str = None,
        size: int = None,
    ):
        self.db = db
        self.key = key
        self.key_type = key_type
        self.node_id = node_id
        self.size = size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db is not None:
            result['Db'] = self.db

        if self.key is not None:
            result['Key'] = self.key

        if self.key_type is not None:
            result['KeyType'] = self.key_type

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.size is not None:
            result['Size'] = self.size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('KeyType') is not None:
            self.key_type = m.get('KeyType')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Size') is not None:
            self.size = m.get('Size')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAutoIncrementUsageStatisticRequest(DaraModel):
    def __init__(
        self,
        db_names: str = None,
        instance_id: str = None,
        ratio_filter: float = None,
        real_time: bool = None,
    ):
        # The database name. If you specify a database, the operation queries the usage of auto-increment table IDs in the specified database. Otherwise, the operation queries the usage of auto-increment table IDs in all databases on the instance.
        # 
        # >  Specify the parameter value as a JSON array, such as [\\"db1\\",\\"db2\\"]. Separate multiple database names with commas (,).
        self.db_names = db_names
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The usage threshold of auto-increment IDs. Only usage that exceeds the threshold can be returned. Valid values are decimals that range from 0 to 1.
        # 
        # This parameter is required.
        self.ratio_filter = ratio_filter
        # Specifies whether to query real-time data. Valid values:
        # 
        # *   **true**: queries data in real time except for data generated in the last 10 minutes.****
        # *   **false**: queries data generated in the last 2 hours. If no such data exists, queries the latest data.
        # 
        # This parameter is required.
        self.real_time = real_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_names is not None:
            result['DbNames'] = self.db_names

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.ratio_filter is not None:
            result['RatioFilter'] = self.ratio_filter

        if self.real_time is not None:
            result['RealTime'] = self.real_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbNames') is not None:
            self.db_names = m.get('DbNames')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('RatioFilter') is not None:
            self.ratio_filter = m.get('RatioFilter')

        if m.get('RealTime') is not None:
            self.real_time = m.get('RealTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeQueryExplainResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: List[main_models.DescribeQueryExplainResponseBodyData] = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        self.code = code
        # List<ExplainedSqlDO>
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.DescribeQueryExplainResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeQueryExplainResponseBodyData(DaraModel):
    def __init__(
        self,
        argument: str = None,
        avg_row_size: str = None,
        defined_values: str = None,
        estimate_cpu: str = None,
        estimate_executions: str = None,
        estimate_io: str = None,
        estimate_rows: str = None,
        extra: str = None,
        id: str = None,
        index_list: List[str] = None,
        key: str = None,
        key_len: str = None,
        logical_op: str = None,
        logical_plan_list: List[str] = None,
        node_id: str = None,
        output_list: str = None,
        parallel: str = None,
        parent: str = None,
        physical_op: str = None,
        possible_keys: str = None,
        query_plan: str = None,
        ref: str = None,
        rows: str = None,
        select_type: str = None,
        stmt_id: str = None,
        stmt_text: str = None,
        table: str = None,
        table_list: List[str] = None,
        total_subtree_cost: str = None,
        type: str = None,
        warnings: str = None,
    ):
        self.argument = argument
        self.avg_row_size = avg_row_size
        self.defined_values = defined_values
        self.estimate_cpu = estimate_cpu
        self.estimate_executions = estimate_executions
        self.estimate_io = estimate_io
        self.estimate_rows = estimate_rows
        self.extra = extra
        self.id = id
        self.index_list = index_list
        self.key = key
        self.key_len = key_len
        self.logical_op = logical_op
        self.logical_plan_list = logical_plan_list
        self.node_id = node_id
        self.output_list = output_list
        self.parallel = parallel
        self.parent = parent
        self.physical_op = physical_op
        self.possible_keys = possible_keys
        self.query_plan = query_plan
        self.ref = ref
        self.rows = rows
        self.select_type = select_type
        self.stmt_id = stmt_id
        self.stmt_text = stmt_text
        self.table = table
        self.table_list = table_list
        self.total_subtree_cost = total_subtree_cost
        self.type = type
        self.warnings = warnings

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.argument is not None:
            result['Argument'] = self.argument

        if self.avg_row_size is not None:
            result['AvgRowSize'] = self.avg_row_size

        if self.defined_values is not None:
            result['DefinedValues'] = self.defined_values

        if self.estimate_cpu is not None:
            result['EstimateCPU'] = self.estimate_cpu

        if self.estimate_executions is not None:
            result['EstimateExecutions'] = self.estimate_executions

        if self.estimate_io is not None:
            result['EstimateIO'] = self.estimate_io

        if self.estimate_rows is not None:
            result['EstimateRows'] = self.estimate_rows

        if self.extra is not None:
            result['Extra'] = self.extra

        if self.id is not None:
            result['Id'] = self.id

        if self.index_list is not None:
            result['IndexList'] = self.index_list

        if self.key is not None:
            result['Key'] = self.key

        if self.key_len is not None:
            result['KeyLen'] = self.key_len

        if self.logical_op is not None:
            result['LogicalOp'] = self.logical_op

        if self.logical_plan_list is not None:
            result['LogicalPlanList'] = self.logical_plan_list

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.output_list is not None:
            result['OutputList'] = self.output_list

        if self.parallel is not None:
            result['Parallel'] = self.parallel

        if self.parent is not None:
            result['Parent'] = self.parent

        if self.physical_op is not None:
            result['PhysicalOp'] = self.physical_op

        if self.possible_keys is not None:
            result['PossibleKeys'] = self.possible_keys

        if self.query_plan is not None:
            result['QueryPlan'] = self.query_plan

        if self.ref is not None:
            result['Ref'] = self.ref

        if self.rows is not None:
            result['Rows'] = self.rows

        if self.select_type is not None:
            result['SelectType'] = self.select_type

        if self.stmt_id is not None:
            result['StmtId'] = self.stmt_id

        if self.stmt_text is not None:
            result['StmtText'] = self.stmt_text

        if self.table is not None:
            result['Table'] = self.table

        if self.table_list is not None:
            result['TableList'] = self.table_list

        if self.total_subtree_cost is not None:
            result['TotalSubtreeCost'] = self.total_subtree_cost

        if self.type is not None:
            result['Type'] = self.type

        if self.warnings is not None:
            result['Warnings'] = self.warnings

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Argument') is not None:
            self.argument = m.get('Argument')

        if m.get('AvgRowSize') is not None:
            self.avg_row_size = m.get('AvgRowSize')

        if m.get('DefinedValues') is not None:
            self.defined_values = m.get('DefinedValues')

        if m.get('EstimateCPU') is not None:
            self.estimate_cpu = m.get('EstimateCPU')

        if m.get('EstimateExecutions') is not None:
            self.estimate_executions = m.get('EstimateExecutions')

        if m.get('EstimateIO') is not None:
            self.estimate_io = m.get('EstimateIO')

        if m.get('EstimateRows') is not None:
            self.estimate_rows = m.get('EstimateRows')

        if m.get('Extra') is not None:
            self.extra = m.get('Extra')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('IndexList') is not None:
            self.index_list = m.get('IndexList')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('KeyLen') is not None:
            self.key_len = m.get('KeyLen')

        if m.get('LogicalOp') is not None:
            self.logical_op = m.get('LogicalOp')

        if m.get('LogicalPlanList') is not None:
            self.logical_plan_list = m.get('LogicalPlanList')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('OutputList') is not None:
            self.output_list = m.get('OutputList')

        if m.get('Parallel') is not None:
            self.parallel = m.get('Parallel')

        if m.get('Parent') is not None:
            self.parent = m.get('Parent')

        if m.get('PhysicalOp') is not None:
            self.physical_op = m.get('PhysicalOp')

        if m.get('PossibleKeys') is not None:
            self.possible_keys = m.get('PossibleKeys')

        if m.get('QueryPlan') is not None:
            self.query_plan = m.get('QueryPlan')

        if m.get('Ref') is not None:
            self.ref = m.get('Ref')

        if m.get('Rows') is not None:
            self.rows = m.get('Rows')

        if m.get('SelectType') is not None:
            self.select_type = m.get('SelectType')

        if m.get('StmtId') is not None:
            self.stmt_id = m.get('StmtId')

        if m.get('StmtText') is not None:
            self.stmt_text = m.get('StmtText')

        if m.get('Table') is not None:
            self.table = m.get('Table')

        if m.get('TableList') is not None:
            self.table_list = m.get('TableList')

        if m.get('TotalSubtreeCost') is not None:
            self.total_subtree_cost = m.get('TotalSubtreeCost')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        if m.get('Warnings') is not None:
            self.warnings = m.get('Warnings')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class UpdateAutoSqlOptimizeStatusResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.UpdateAutoSqlOptimizeStatusResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.UpdateAutoSqlOptimizeStatusResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class UpdateAutoSqlOptimizeStatusResponseBodyData(DaraModel):
    def __init__(
        self,
        error_code: str = None,
        error_msg: str = None,
        success: str = None,
    ):
        # The error code. Valid values:
        # 
        # *   **-1001**: indicates that the specified parameter is invalid.
        # *   **-91029**: indicates that a system error occurred.
        self.error_code = error_code
        # The error message.
        self.error_msg = error_msg
        # Indicates whether the request initiated to configure the automatic SQL optimization feature was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.error_code is not None:
            result['ErrorCode'] = self.error_code

        if self.error_msg is not None:
            result['ErrorMsg'] = self.error_msg

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ErrorCode') is not None:
            self.error_code = m.get('ErrorCode')

        if m.get('ErrorMsg') is not None:
            self.error_msg = m.get('ErrorMsg')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetInstanceSqlOptimizeStatisticRequest(DaraModel):
    def __init__(
        self,
        end_time: str = None,
        filter_enable: str = None,
        instance_id: str = None,
        node_id: str = None,
        start_time: str = None,
        threshold: str = None,
        use_merging: str = None,
    ):
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # This parameter is required.
        self.end_time = end_time
        # Specifies whether to filter instances for which DAS Enterprise Edition is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        # 
        # >  If you set this parameter to **true**, only database instances for which DAS Enterprise Edition is disabled are queried. If you set this parameter to **false**, all database instances are queried.
        self.filter_enable = filter_enable
        # The database instance ID.
        # 
        # >  The database instance must be an ApsaraDB RDS for MySQL instance or a PolarDB for MySQL cluster.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The node ID.
        # 
        # >  For ApsaraDB RDS for MySQL Cluster Edition instances or PolarDB for MySQL clusters, you must specify the node ID.
        self.node_id = node_id
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # This parameter is required.
        self.start_time = start_time
        # The duration threshold for automatic SQL optimization events. After this parameter is specified, the system collects statistics on automatic SQL optimization events whose duration does not exceed the specified threshold.
        # 
        # >  This parameter is a reserved parameter and does not take effect.
        self.threshold = threshold
        # Specifies whether to merge automatic SQL optimization events. Valid values:
        # 
        # *   **true**: merges automatic SQL optimization events.
        # *   **false**: does not merge automatic SQL optimization events.
        # 
        # >  This parameter is a reserved parameter and does not take effect.
        self.use_merging = use_merging

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.filter_enable is not None:
            result['FilterEnable'] = self.filter_enable

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.threshold is not None:
            result['Threshold'] = self.threshold

        if self.use_merging is not None:
            result['UseMerging'] = self.use_merging

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('FilterEnable') is not None:
            self.filter_enable = m.get('FilterEnable')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('Threshold') is not None:
            self.threshold = m.get('Threshold')

        if m.get('UseMerging') is not None:
            self.use_merging = m.get('UseMerging')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetMySQLAllSessionAsyncRequest(DaraModel):
    def __init__(
        self,
        instance_id: str = None,
        node_id: str = None,
        result_id: str = None,
    ):
        # The instance ID.
        # 
        # >  Only ApsaraDB RDS for MySQL, PolarDB for MySQL, and PolarDB-X 2.0 instances are supported.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The node ID.
        # 
        # >  You must specify this parameter for PolarDB for MySQL clusters. If you do not specify a node ID, the session data of the primary node is returned by default.
        self.node_id = node_id
        # The asynchronous request ID.
        # 
        # >  GetMySQLAllSessionAsync is an asynchronous operation. After a request is sent, the system does not return complete results but returns a **request ID**. You need to use the **request ID** to initiate requests until the value of the **isFinish** field in the returned results is **true**, the complete results are returned. This indicates that to obtain complete data, you must call this operation at least twice.
        self.result_id = result_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.result_id is not None:
            result['ResultId'] = self.result_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('ResultId') is not None:
            self.result_id = m.get('ResultId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSecurityIPGroupResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeSecurityIPGroupResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        self.code = code
        # ListResult<InstanceSSL>
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeSecurityIPGroupResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeSecurityIPGroupResponseBodyData(DaraModel):
    def __init__(
        self,
        security_ip_groups: List[main_models.DescribeSecurityIPGroupResponseBodyDataSecurityIpGroups] = None,
    ):
        self.security_ip_groups = security_ip_groups

    def validate(self):
        if self.security_ip_groups:
            for v1 in self.security_ip_groups:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['SecurityIpGroups'] = []
        if self.security_ip_groups is not None:
            for k1 in self.security_ip_groups:
                result['SecurityIpGroups'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.security_ip_groups = []
        if m.get('SecurityIpGroups') is not None:
            for k1 in m.get('SecurityIpGroups'):
                temp_model = main_models.DescribeSecurityIPGroupResponseBodyDataSecurityIpGroups()
                self.security_ip_groups.append(temp_model.from_map(k1))

        return self

class DescribeSecurityIPGroupResponseBodyDataSecurityIpGroups(DaraModel):
    def __init__(
        self,
        db_instances: List[str] = None,
        engine_info_list: List[main_models.DescribeSecurityIPGroupResponseBodyDataSecurityIpGroupsEngineInfoList] = None,
        gecs_sg_id_list: str = None,
        gip_list: str = None,
        global_ig_name: str = None,
        global_security_group_id: str = None,
        region_id: str = None,
        security_ip_type: str = None,
        uid: str = None,
        user_id: str = None,
        whitelist_net_type: str = None,
    ):
        self.db_instances = db_instances
        self.engine_info_list = engine_info_list
        self.gecs_sg_id_list = gecs_sg_id_list
        self.gip_list = gip_list
        self.global_ig_name = global_ig_name
        self.global_security_group_id = global_security_group_id
        self.region_id = region_id
        self.security_ip_type = security_ip_type
        self.uid = uid
        self.user_id = user_id
        self.whitelist_net_type = whitelist_net_type

    def validate(self):
        if self.engine_info_list:
            for v1 in self.engine_info_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_instances is not None:
            result['DbInstances'] = self.db_instances

        result['EngineInfoList'] = []
        if self.engine_info_list is not None:
            for k1 in self.engine_info_list:
                result['EngineInfoList'].append(k1.to_map() if k1 else None)

        if self.gecs_sg_id_list is not None:
            result['GEcsSgIdList'] = self.gecs_sg_id_list

        if self.gip_list is not None:
            result['GIpList'] = self.gip_list

        if self.global_ig_name is not None:
            result['GlobalIgName'] = self.global_ig_name

        if self.global_security_group_id is not None:
            result['GlobalSecurityGroupId'] = self.global_security_group_id

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.security_ip_type is not None:
            result['SecurityIpType'] = self.security_ip_type

        if self.uid is not None:
            result['Uid'] = self.uid

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.whitelist_net_type is not None:
            result['WhitelistNetType'] = self.whitelist_net_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbInstances') is not None:
            self.db_instances = m.get('DbInstances')

        self.engine_info_list = []
        if m.get('EngineInfoList') is not None:
            for k1 in m.get('EngineInfoList'):
                temp_model = main_models.DescribeSecurityIPGroupResponseBodyDataSecurityIpGroupsEngineInfoList()
                self.engine_info_list.append(temp_model.from_map(k1))

        if m.get('GEcsSgIdList') is not None:
            self.gecs_sg_id_list = m.get('GEcsSgIdList')

        if m.get('GIpList') is not None:
            self.gip_list = m.get('GIpList')

        if m.get('GlobalIgName') is not None:
            self.global_ig_name = m.get('GlobalIgName')

        if m.get('GlobalSecurityGroupId') is not None:
            self.global_security_group_id = m.get('GlobalSecurityGroupId')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('SecurityIpType') is not None:
            self.security_ip_type = m.get('SecurityIpType')

        if m.get('Uid') is not None:
            self.uid = m.get('Uid')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('WhitelistNetType') is not None:
            self.whitelist_net_type = m.get('WhitelistNetType')

        return self

class DescribeSecurityIPGroupResponseBodyDataSecurityIpGroupsEngineInfoList(DaraModel):
    def __init__(
        self,
        engine_name: str = None,
        instance_ids: List[str] = None,
        instance_num: int = None,
    ):
        self.engine_name = engine_name
        self.instance_ids = instance_ids
        self.instance_num = instance_num

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.engine_name is not None:
            result['EngineName'] = self.engine_name

        if self.instance_ids is not None:
            result['InstanceIds'] = self.instance_ids

        if self.instance_num is not None:
            result['InstanceNum'] = self.instance_num

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EngineName') is not None:
            self.engine_name = m.get('EngineName')

        if m.get('InstanceIds') is not None:
            self.instance_ids = m.get('InstanceIds')

        if m.get('InstanceNum') is not None:
            self.instance_num = m.get('InstanceNum')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAsyncErrorRequestStatResultRequest(DaraModel):
    def __init__(
        self,
        db_name: str = None,
        end: int = None,
        instance_id: str = None,
        node_id: str = None,
        sql_id_list: str = None,
        start: int = None,
    ):
        # The name of the database.
        self.db_name = db_name
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The end time must be later than the start time. The interval between the start time and the end time cannot exceed 24 hours.
        self.end = end
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The node ID.
        # 
        # >  This parameter must be specified for PolarDB for MySQL instances.
        self.node_id = node_id
        # The ID of the SQL template. Separate multiple SQL IDs with commas (,). You can call the [GetAsyncErrorRequestListByCode](https://help.aliyun.com/document_detail/410746.html) operation to query the ID of the SQL query for which MySQL error code is returned.
        self.sql_id_list = sql_id_list
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The beginning of the time range to query must be within the storage duration of the database instance and can be up to 90 days earlier than the current time.
        self.start = start

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_name is not None:
            result['DbName'] = self.db_name

        if self.end is not None:
            result['End'] = self.end

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.sql_id_list is not None:
            result['SqlIdList'] = self.sql_id_list

        if self.start is not None:
            result['Start'] = self.start

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbName') is not None:
            self.db_name = m.get('DbName')

        if m.get('End') is not None:
            self.end = m.get('End')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('SqlIdList') is not None:
            self.sql_id_list = m.get('SqlIdList')

        if m.get('Start') is not None:
            self.start = m.get('Start')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeHotKeysResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeHotKeysResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, Successful is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeHotKeysResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeHotKeysResponseBodyData(DaraModel):
    def __init__(
        self,
        hot_key: List[main_models.DescribeHotKeysResponseBodyDataHotKey] = None,
    ):
        self.hot_key = hot_key

    def validate(self):
        if self.hot_key:
            for v1 in self.hot_key:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['HotKey'] = []
        if self.hot_key is not None:
            for k1 in self.hot_key:
                result['HotKey'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.hot_key = []
        if m.get('HotKey') is not None:
            for k1 in m.get('HotKey'):
                temp_model = main_models.DescribeHotKeysResponseBodyDataHotKey()
                self.hot_key.append(temp_model.from_map(k1))

        return self

class DescribeHotKeysResponseBodyDataHotKey(DaraModel):
    def __init__(
        self,
        category: str = None,
        db: int = None,
        hot: str = None,
        in_bytes: int = None,
        key: str = None,
        key_type: str = None,
        node_id: str = None,
        out_bytes: int = None,
        size: int = None,
    ):
        self.category = category
        self.db = db
        self.hot = hot
        self.in_bytes = in_bytes
        self.key = key
        self.key_type = key_type
        self.node_id = node_id
        self.out_bytes = out_bytes
        self.size = size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.category is not None:
            result['Category'] = self.category

        if self.db is not None:
            result['Db'] = self.db

        if self.hot is not None:
            result['Hot'] = self.hot

        if self.in_bytes is not None:
            result['InBytes'] = self.in_bytes

        if self.key is not None:
            result['Key'] = self.key

        if self.key_type is not None:
            result['KeyType'] = self.key_type

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.out_bytes is not None:
            result['OutBytes'] = self.out_bytes

        if self.size is not None:
            result['Size'] = self.size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Category') is not None:
            self.category = m.get('Category')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Hot') is not None:
            self.hot = m.get('Hot')

        if m.get('InBytes') is not None:
            self.in_bytes = m.get('InBytes')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('KeyType') is not None:
            self.key_type = m.get('KeyType')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('OutBytes') is not None:
            self.out_bytes = m.get('OutBytes')

        if m.get('Size') is not None:
            self.size = m.get('Size')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetPfsMetricTrendsRequest(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        instance_id: str = None,
        metric: str = None,
        node_id: str = None,
        start_time: int = None,
    ):
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The end time must be later than the start time. You can view the data of up to seven days in the previous 30 days.
        self.end_time = end_time
        # The instance ID.
        self.instance_id = instance_id
        # The metric whose trend you want to query. Valid values:
        # 
        # *   **count**: the number of executions.
        # *   **avgRt**: the average execution duration.
        # *   **rtRate**: the execution duration percentage.
        # *   **rowsExamined**: the total number of scanned rows.
        self.metric = metric
        # The node ID.
        # 
        # >  This parameter is required if the database instance is an ApsaraDB RDS for MySQL Cluster Edition instance or a PolarDB for MySQL clusters.
        self.node_id = node_id
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.metric is not None:
            result['Metric'] = self.metric

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Metric') is not None:
            self.metric = m.get('Metric')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAutoResourceOptimizeRulesRequest(DaraModel):
    def __init__(
        self,
        console_context: str = None,
        instance_ids: str = None,
    ):
        # The reserved parameter.
        self.console_context = console_context
        # The database instance IDs.
        # 
        # *   Specify the parameter value as a JSON array, such as `[\\"Database account 1\\",\\"Database account 2\\"]`. Separate database instance IDs with commas (,).
        # 
        # *   By default, if you leave this parameter empty, all database instances for which the automatic fragment recycling feature has been enabled within the current Alibaba Cloud account are returned. The following types of database instances are returned:
        # 
        #     *   Database instances for which the automatic fragment recycling feature is currently enabled.
        #     *   Database instances for which the automatic fragment recycling feature was once enabled but is currently disabled, including those for which DAS Enterprise Edition has been disabled but excluding those that have been released.
        self.instance_ids = instance_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.console_context is not None:
            result['ConsoleContext'] = self.console_context

        if self.instance_ids is not None:
            result['InstanceIds'] = self.instance_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConsoleContext') is not None:
            self.console_context = m.get('ConsoleContext')

        if m.get('InstanceIds') is not None:
            self.instance_ids = m.get('InstanceIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAutoThrottleRulesRequest(DaraModel):
    def __init__(
        self,
        console_context: str = None,
        instance_ids: str = None,
    ):
        # The reserved parameter.
        self.console_context = console_context
        # The database instance IDs.
        # 
        # *   Set this parameter to a JSON array that consists of multiple instance IDs. Separate instance IDs with commas (,). Example: `[\\"Instance ID1\\",\\"Instance ID2\\"]`.
        # 
        # *   By default, if you leave this parameter empty, all database instances for which the automatic SQL throttling feature has been enabled within the current Alibaba Cloud account are returned. The following types of database instances are returned:
        # 
        #     *   Database instances for which the automatic SQL throttling feature is currently enabled.
        #     *   Database instances for which the automatic SQL throttling feature was once enabled but is currently disabled. Released database instances are not included.
        self.instance_ids = instance_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.console_context is not None:
            result['ConsoleContext'] = self.console_context

        if self.instance_ids is not None:
            result['InstanceIds'] = self.instance_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConsoleContext') is not None:
            self.console_context = m.get('ConsoleContext')

        if m.get('InstanceIds') is not None:
            self.instance_ids = m.get('InstanceIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetMySQLAllSessionAsyncResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetMySQLAllSessionAsyncResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetMySQLAllSessionAsyncResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetMySQLAllSessionAsyncResponseBodyData(DaraModel):
    def __init__(
        self,
        complete: bool = None,
        fail: bool = None,
        is_finish: bool = None,
        result_id: str = None,
        session_data: main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionData = None,
        state: str = None,
        timestamp: int = None,
    ):
        # Indicates whether the asynchronous request was complete. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.complete = complete
        # Indicates whether the asynchronous request failed. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.fail = fail
        # Indicates whether the asynchronous request was complete. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.is_finish = is_finish
        # The ID of the asynchronous request.
        self.result_id = result_id
        # The session data.
        self.session_data = session_data
        # The state of the asynchronous request. Valid values:
        # 
        # *   **RUNNING**
        # *   **SUCCESS**
        # *   **FAIL**
        self.state = state
        # The time when the asynchronous request was made. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp

    def validate(self):
        if self.session_data:
            self.session_data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.complete is not None:
            result['Complete'] = self.complete

        if self.fail is not None:
            result['Fail'] = self.fail

        if self.is_finish is not None:
            result['IsFinish'] = self.is_finish

        if self.result_id is not None:
            result['ResultId'] = self.result_id

        if self.session_data is not None:
            result['SessionData'] = self.session_data.to_map()

        if self.state is not None:
            result['State'] = self.state

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Complete') is not None:
            self.complete = m.get('Complete')

        if m.get('Fail') is not None:
            self.fail = m.get('Fail')

        if m.get('IsFinish') is not None:
            self.is_finish = m.get('IsFinish')

        if m.get('ResultId') is not None:
            self.result_id = m.get('ResultId')

        if m.get('SessionData') is not None:
            temp_model = main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionData()
            self.session_data = temp_model.from_map(m.get('SessionData'))

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        return self

class GetMySQLAllSessionAsyncResponseBodyDataSessionData(DaraModel):
    def __init__(
        self,
        active_session_count: int = None,
        client_stats: List[main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataClientStats] = None,
        db_stats: List[main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataDbStats] = None,
        max_active_time: int = None,
        session_list: List[main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataSessionList] = None,
        time_stamp: int = None,
        total_session_count: int = None,
        user_stats: List[main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataUserStats] = None,
    ):
        # The total number of active sessions.
        self.active_session_count = active_session_count
        # The sessions that are counted by client IP address.
        self.client_stats = client_stats
        # The sessions that are counted by database.
        self.db_stats = db_stats
        # The maximum execution duration of an active session. Unit: seconds.
        self.max_active_time = max_active_time
        # The sessions.
        self.session_list = session_list
        # The time when the session was queried. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.time_stamp = time_stamp
        # The total number of sessions.
        self.total_session_count = total_session_count
        # The sessions that are counted by database account.
        self.user_stats = user_stats

    def validate(self):
        if self.client_stats:
            for v1 in self.client_stats:
                 if v1:
                    v1.validate()
        if self.db_stats:
            for v1 in self.db_stats:
                 if v1:
                    v1.validate()
        if self.session_list:
            for v1 in self.session_list:
                 if v1:
                    v1.validate()
        if self.user_stats:
            for v1 in self.user_stats:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active_session_count is not None:
            result['ActiveSessionCount'] = self.active_session_count

        result['ClientStats'] = []
        if self.client_stats is not None:
            for k1 in self.client_stats:
                result['ClientStats'].append(k1.to_map() if k1 else None)

        result['DbStats'] = []
        if self.db_stats is not None:
            for k1 in self.db_stats:
                result['DbStats'].append(k1.to_map() if k1 else None)

        if self.max_active_time is not None:
            result['MaxActiveTime'] = self.max_active_time

        result['SessionList'] = []
        if self.session_list is not None:
            for k1 in self.session_list:
                result['SessionList'].append(k1.to_map() if k1 else None)

        if self.time_stamp is not None:
            result['TimeStamp'] = self.time_stamp

        if self.total_session_count is not None:
            result['TotalSessionCount'] = self.total_session_count

        result['UserStats'] = []
        if self.user_stats is not None:
            for k1 in self.user_stats:
                result['UserStats'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ActiveSessionCount') is not None:
            self.active_session_count = m.get('ActiveSessionCount')

        self.client_stats = []
        if m.get('ClientStats') is not None:
            for k1 in m.get('ClientStats'):
                temp_model = main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataClientStats()
                self.client_stats.append(temp_model.from_map(k1))

        self.db_stats = []
        if m.get('DbStats') is not None:
            for k1 in m.get('DbStats'):
                temp_model = main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataDbStats()
                self.db_stats.append(temp_model.from_map(k1))

        if m.get('MaxActiveTime') is not None:
            self.max_active_time = m.get('MaxActiveTime')

        self.session_list = []
        if m.get('SessionList') is not None:
            for k1 in m.get('SessionList'):
                temp_model = main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataSessionList()
                self.session_list.append(temp_model.from_map(k1))

        if m.get('TimeStamp') is not None:
            self.time_stamp = m.get('TimeStamp')

        if m.get('TotalSessionCount') is not None:
            self.total_session_count = m.get('TotalSessionCount')

        self.user_stats = []
        if m.get('UserStats') is not None:
            for k1 in m.get('UserStats'):
                temp_model = main_models.GetMySQLAllSessionAsyncResponseBodyDataSessionDataUserStats()
                self.user_stats.append(temp_model.from_map(k1))

        return self

class GetMySQLAllSessionAsyncResponseBodyDataSessionDataUserStats(DaraModel):
    def __init__(
        self,
        active_count: int = None,
        key: str = None,
        thread_id_list: List[int] = None,
        total_count: int = None,
        user_list: List[str] = None,
    ):
        # The number of active sessions within the account.
        # 
        # >  If the type of the command executed in the session is Query or Execute and the session in the transaction is not terminated, the session is active.
        self.active_count = active_count
        # The database account.
        self.key = key
        # The IDs of the sessions within the account.
        self.thread_id_list = thread_id_list
        # The total number of sessions within the account.
        self.total_count = total_count
        # The database accounts to which the sessions belong.
        self.user_list = user_list

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active_count is not None:
            result['ActiveCount'] = self.active_count

        if self.key is not None:
            result['Key'] = self.key

        if self.thread_id_list is not None:
            result['ThreadIdList'] = self.thread_id_list

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        if self.user_list is not None:
            result['UserList'] = self.user_list

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ActiveCount') is not None:
            self.active_count = m.get('ActiveCount')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('ThreadIdList') is not None:
            self.thread_id_list = m.get('ThreadIdList')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        if m.get('UserList') is not None:
            self.user_list = m.get('UserList')

        return self

class GetMySQLAllSessionAsyncResponseBodyDataSessionDataSessionList(DaraModel):
    def __init__(
        self,
        client: str = None,
        command: str = None,
        db_name: str = None,
        session_id: int = None,
        sql_template_id: str = None,
        sql_text: str = None,
        state: str = None,
        time: int = None,
        trx_duration: int = None,
        trx_id: str = None,
        user: str = None,
        user_client_alias: str = None,
    ):
        # The IP address of the client.
        self.client = client
        # The type of the command executed in the session.
        self.command = command
        # The database name.
        self.db_name = db_name
        # The session ID.
        self.session_id = session_id
        # The SQL template ID.
        # 
        # >  This parameter is returned only when you use a PolarDB-X 2.0 instance.
        self.sql_template_id = sql_template_id
        # The SQL statement executed in the session.
        self.sql_text = sql_text
        # The status of the session.
        self.state = state
        # The execution duration of the session. Unit: seconds.
        self.time = time
        # The duration of the transaction. Unit: seconds.
        self.trx_duration = trx_duration
        # The ID of the transaction to which the session belongs.
        self.trx_id = trx_id
        # The username of the database account.
        self.user = user
        # The alias of the IP address of the client.
        self.user_client_alias = user_client_alias

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client is not None:
            result['Client'] = self.client

        if self.command is not None:
            result['Command'] = self.command

        if self.db_name is not None:
            result['DbName'] = self.db_name

        if self.session_id is not None:
            result['SessionId'] = self.session_id

        if self.sql_template_id is not None:
            result['SqlTemplateId'] = self.sql_template_id

        if self.sql_text is not None:
            result['SqlText'] = self.sql_text

        if self.state is not None:
            result['State'] = self.state

        if self.time is not None:
            result['Time'] = self.time

        if self.trx_duration is not None:
            result['TrxDuration'] = self.trx_duration

        if self.trx_id is not None:
            result['TrxId'] = self.trx_id

        if self.user is not None:
            result['User'] = self.user

        if self.user_client_alias is not None:
            result['UserClientAlias'] = self.user_client_alias

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Client') is not None:
            self.client = m.get('Client')

        if m.get('Command') is not None:
            self.command = m.get('Command')

        if m.get('DbName') is not None:
            self.db_name = m.get('DbName')

        if m.get('SessionId') is not None:
            self.session_id = m.get('SessionId')

        if m.get('SqlTemplateId') is not None:
            self.sql_template_id = m.get('SqlTemplateId')

        if m.get('SqlText') is not None:
            self.sql_text = m.get('SqlText')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Time') is not None:
            self.time = m.get('Time')

        if m.get('TrxDuration') is not None:
            self.trx_duration = m.get('TrxDuration')

        if m.get('TrxId') is not None:
            self.trx_id = m.get('TrxId')

        if m.get('User') is not None:
            self.user = m.get('User')

        if m.get('UserClientAlias') is not None:
            self.user_client_alias = m.get('UserClientAlias')

        return self

class GetMySQLAllSessionAsyncResponseBodyDataSessionDataDbStats(DaraModel):
    def __init__(
        self,
        active_count: int = None,
        key: str = None,
        thread_id_list: List[int] = None,
        total_count: int = None,
        user_list: List[str] = None,
    ):
        # The number of active sessions of the database.
        # 
        # >  If the type of the command executed in the session is Query or Execute and the session in the transaction is not terminated, the session is active.
        self.active_count = active_count
        # The database name.
        self.key = key
        # The IDs of the sessions of the database.
        self.thread_id_list = thread_id_list
        # The total number of sessions of the database.
        self.total_count = total_count
        # The database accounts to which the sessions belong.
        self.user_list = user_list

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active_count is not None:
            result['ActiveCount'] = self.active_count

        if self.key is not None:
            result['Key'] = self.key

        if self.thread_id_list is not None:
            result['ThreadIdList'] = self.thread_id_list

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        if self.user_list is not None:
            result['UserList'] = self.user_list

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ActiveCount') is not None:
            self.active_count = m.get('ActiveCount')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('ThreadIdList') is not None:
            self.thread_id_list = m.get('ThreadIdList')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        if m.get('UserList') is not None:
            self.user_list = m.get('UserList')

        return self

class GetMySQLAllSessionAsyncResponseBodyDataSessionDataClientStats(DaraModel):
    def __init__(
        self,
        active_count: int = None,
        key: str = None,
        thread_id_list: List[int] = None,
        total_count: int = None,
        user_list: List[str] = None,
    ):
        # The number of active sessions that belong to the client IP address.
        # 
        # >  If the type of the command executed in the session is Query or Execute and the session in the transaction is not terminated, the session is active.
        self.active_count = active_count
        # The IP address of the client.
        self.key = key
        # The IDs of the sessions that belong to the client IP address.
        self.thread_id_list = thread_id_list
        # The total number of sessions that belong to the client IP address.
        self.total_count = total_count
        # The database accounts to which the sessions belong.
        self.user_list = user_list

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active_count is not None:
            result['ActiveCount'] = self.active_count

        if self.key is not None:
            result['Key'] = self.key

        if self.thread_id_list is not None:
            result['ThreadIdList'] = self.thread_id_list

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        if self.user_list is not None:
            result['UserList'] = self.user_list

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ActiveCount') is not None:
            self.active_count = m.get('ActiveCount')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('ThreadIdList') is not None:
            self.thread_id_list = m.get('ThreadIdList')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        if m.get('UserList') is not None:
            self.user_list = m.get('UserList')

        return self

